Plugin: JS9Layers

### JS9 Shape Layers

JS9 supports individual layers for drawing 2D graphics. The regions layer is a special case of a shape layer, created automatically by JS9. The Catalog Plugin creates a separate layer for each catalog. You can define your own shape layer using the NewShapeLayer() public routine, and then add geometric shapes to it.

For a given image, one shape layer at a time is active, responding to mouse and touch events. Ordinarily, a shape layer becomes the active layer when it is first created and shapes are added to it. Thus, the first time you create a region, the regions layer becomes active. If you then load a catalog into a catalog layer, that layer becomes active.

The Shape Layers plugin displays the layers defined for the current image and allows you to turn on and off the display of any layer. It highlights the currently active layer (the topmost visible layer in the layer stack) allows you to make a layer active by moving it to the top of the stack.

You also can save layers to a local file. If the layer is a catalog (i.e., a tab-delimited table loaded using LoadCatalog() or the load catalog menu option), you will have the choice of saving the layer either as a catalog or a region. Otherwise, you will be able to save the layer as a region.